@@ -104,7 +104,7 @@ antlr3LexerNew(ANTLR3_UINT32 sizeHint, pANTLR3_RECOGNIZER_SHARED_STATE state)
 	*/
 	if	(lexer->rec->state->tokSource == NULL) 
 	{
-		lexer->rec->state->tokSource	= (pANTLR3_TOKEN_SOURCE)ANTLR3_MALLOC(sizeof(ANTLR3_TOKEN_SOURCE));
+		lexer->rec->state->tokSource	= (pANTLR3_TOKEN_SOURCE)ANTLR3_CALLOC(1, sizeof(ANTLR3_TOKEN_SOURCE));
 
 		if	(lexer->rec->state->tokSource == NULL) 
 		{
@@ -146,19 +146,28 @@ antlr3LexerNew(ANTLR3_UINT32 sizeHint, pANTLR3_RECOGNIZER_SHARED_STATE state)
     
     /* Initialise the eof token
      */
-    specialT				= &(lexer->rec->state->tokSource->eofToken);
+    specialT					= &(lexer->rec->state->tokSource->eofToken);
     antlr3SetTokenAPI	  (specialT);
     specialT->setType	  (specialT, ANTLR3_TOKEN_EOF);
-    specialT->factoryMade	= ANTLR3_TRUE;					// Prevent things trying to free() it
-    specialT->strFactory    = NULL;
+    specialT->factoryMade		= ANTLR3_TRUE;					// Prevent things trying to free() it
+    specialT->strFactory        = NULL;
+	specialT->textState			= ANTLR3_TEXT_NONE;
+	specialT->custom			= NULL;
+	specialT->user1				= 0;
+	specialT->user2				= 0;
+	specialT->user3				= 0;
 
 	// Initialize the skip token.
 	//
-    specialT				= &(lexer->rec->state->tokSource->skipToken);
+    specialT					= &(lexer->rec->state->tokSource->skipToken);
     antlr3SetTokenAPI	  (specialT);
     specialT->setType	  (specialT, ANTLR3_TOKEN_INVALID);
-    specialT->factoryMade	= ANTLR3_TRUE;					// Prevent things trying to free() it
-    specialT->strFactory    = NULL;
+    specialT->factoryMade		= ANTLR3_TRUE;					// Prevent things trying to free() it
+    specialT->strFactory        = NULL;
+	specialT->custom			= NULL;
+	specialT->user1				= 0;
+	specialT->user2				= 0;
+	specialT->user3				= 0;
     return  lexer;
 }
 
@@ -169,18 +178,21 @@ reset	(pANTLR3_BASE_RECOGNIZER rec)
 
     lexer   = rec->super;
 
-    lexer->rec->state->token			= NULL;
-    lexer->rec->state->type				= ANTLR3_TOKEN_INVALID;
-    lexer->rec->state->channel			= ANTLR3_TOKEN_DEFAULT_CHANNEL;
-    lexer->rec->state->tokenStartCharIndex		= -1;
+    lexer->rec->state->token			    = NULL;
+    lexer->rec->state->type			    = ANTLR3_TOKEN_INVALID;
+    lexer->rec->state->channel			    = ANTLR3_TOKEN_DEFAULT_CHANNEL;
+    lexer->rec->state->tokenStartCharIndex	    = -1;
     lexer->rec->state->tokenStartCharPositionInLine = -1;
-    lexer->rec->state->tokenStartLine		= -1;
+    lexer->rec->state->tokenStartLine		    = -1;
 
-    lexer->rec->state->text	    = NULL;
+    lexer->rec->state->text	                    = NULL;
 
-    if (lexer->input != NULL)
+    // OK - that's all hunky dory, but we may well have had
+    // a token factory that needs a reset. Do that here
+    //
+    if  (lexer->rec->state->tokFactory != NULL)
     {
-	lexer->input->istream->seek(lexer->input->istream, 0);
+        lexer->rec->state->tokFactory->reset(lexer->rec->state->tokFactory);
     }
 }
 
@@ -204,87 +216,95 @@ reset	(pANTLR3_BASE_RECOGNIZER rec)
 ANTLR3_INLINE static pANTLR3_COMMON_TOKEN
 nextTokenStr	    (pANTLR3_TOKEN_SOURCE toksource)
 {
-	pANTLR3_LEXER   lexer;
+    pANTLR3_LEXER                   lexer;
+    pANTLR3_RECOGNIZER_SHARED_STATE state;
+    pANTLR3_INPUT_STREAM            input;
+    pANTLR3_INT_STREAM              istream;
 
-	lexer   = (pANTLR3_LEXER)(toksource->super);
+    lexer   = (pANTLR3_LEXER)(toksource->super);
+    state   = lexer->rec->state;
+    input   = lexer->input;
+    istream = input->istream;
 
-	/// Loop until we get a non skipped token or EOF
-	///
-	for	(;;)
-	{
-		// Get rid of any previous token (token factory takes care of
-		// any de-allocation when this token is finally used up.
-		//
-		lexer->rec->state->token		    = NULL;
-		lexer->rec->state->error		    = ANTLR3_FALSE;	    // Start out without an exception
-		lexer->rec->state->failed		    = ANTLR3_FALSE;
+    /// Loop until we get a non skipped token or EOF
+    ///
+    for	(;;)
+    {
+        // Get rid of any previous token (token factory takes care of
+        // any de-allocation when this token is finally used up.
+        //
+        state->token		    = NULL;
+        state->error		    = ANTLR3_FALSE;	    // Start out without an exception
+        state->failed		    = ANTLR3_FALSE;
 
-
-
-		// Now call the matching rules and see if we can generate a new token
-		//
-		for	(;;)
-		{
+        // Now call the matching rules and see if we can generate a new token
+        //
+        for	(;;)
+        {
             // Record the start of the token in our input stream.
             //
-            lexer->rec->state->channel						= ANTLR3_TOKEN_DEFAULT_CHANNEL;
-            lexer->rec->state->tokenStartCharIndex			= lexer->input->istream->index(lexer->input->istream);
-            lexer->rec->state->tokenStartCharPositionInLine	= lexer->input->getCharPositionInLine(lexer->input);
-        	lexer->rec->state->tokenStartLine				= lexer->input->getLine(lexer->input);
-            lexer->rec->state->text							= NULL;
+            state->channel			    = ANTLR3_TOKEN_DEFAULT_CHANNEL;
+            state->tokenStartCharIndex	            = (ANTLR3_MARKER)(((pANTLR3_UINT8)input->nextChar));
+            state->tokenStartCharPositionInLine     = input->charPositionInLine;
+            state->tokenStartLine		    = input->line;
+            state->text			            = NULL;
+            state->custom                           = NULL;
+            state->user1                            = 0;
+            state->user2                            = 0;
+            state->user3                            = 0;
 
-			if  (lexer->input->istream->_LA(lexer->input->istream, 1) == ANTLR3_CHARSTREAM_EOF)
-			{
-				// Reached the end of the current stream, nothing more to do if this is
-				// the last in the stack.
-				//
-				pANTLR3_COMMON_TOKEN    teof = &(toksource->eofToken);
+            if  (istream->_LA(istream, 1) == ANTLR3_CHARSTREAM_EOF)
+            {
+                // Reached the end of the current stream, nothing more to do if this is
+                // the last in the stack.
+                //
+                pANTLR3_COMMON_TOKEN    teof = &(toksource->eofToken);
 
-				teof->setStartIndex (teof, lexer->getCharIndex(lexer));
-				teof->setStopIndex  (teof, lexer->getCharIndex(lexer));
-				teof->setLine	(teof, lexer->getLine(lexer));
-				teof->factoryMade = ANTLR3_TRUE;	// This isn't really manufactured but it stops things from trying to free it
-				return  teof;
-			}
+                teof->setStartIndex (teof, lexer->getCharIndex(lexer));
+                teof->setStopIndex  (teof, lexer->getCharIndex(lexer));
+                teof->setLine	    (teof, lexer->getLine(lexer));
+                teof->factoryMade = ANTLR3_TRUE;	// This isn't really manufactured but it stops things from trying to free it
+                return  teof;
+            }
 
-			lexer->rec->state->token		= NULL;
-			lexer->rec->state->error		= ANTLR3_FALSE;	    // Start out without an exception
-			lexer->rec->state->failed		= ANTLR3_FALSE;
+            state->token		= NULL;
+            state->error		= ANTLR3_FALSE;	    // Start out without an exception
+            state->failed		= ANTLR3_FALSE;
 
-			// Call the generated lexer, see if it can get a new token together.
-			//
-			lexer->mTokens(lexer->ctx);
+            // Call the generated lexer, see if it can get a new token together.
+            //
+            lexer->mTokens(lexer->ctx);
 
-			if  (lexer->rec->state->error  == ANTLR3_TRUE)
-			{
-				// Recognition exception, report it and try to recover.
-				//
-				lexer->rec->state->failed	    = ANTLR3_TRUE;
-				lexer->rec->reportError(lexer->rec);
-				lexer->recover(lexer); 
-			}
-			else
-			{
-				if (lexer->rec->state->token == NULL)
-				{
-					// Emit the real token, which adds it in to the token stream basically
-					//
-					emit(lexer);
-				}
-				else if	(lexer->rec->state->token ==  &(toksource->skipToken))
-				{
-					// A real token could have been generated, but "Computer say's naaaaah" and it
-					// it is just something we need to skip altogether.
-					//
-					continue;
-				}
-				
-				// Good token, not skipped, not EOF token
-				//
-				return  lexer->rec->state->token;
-			}
-		}
-	}
+            if  (state->error  == ANTLR3_TRUE)
+            {
+                // Recognition exception, report it and try to recover.
+                //
+                state->failed	    = ANTLR3_TRUE;
+                lexer->rec->reportError(lexer->rec);
+                lexer->recover(lexer); 
+            }
+            else
+            {
+                if (state->token == NULL)
+                {
+                    // Emit the real token, which adds it in to the token stream basically
+                    //
+                    emit(lexer);
+                }
+                else if	(state->token ==  &(toksource->skipToken))
+                {
+                    // A real token could have been generated, but "Computer say's naaaaah" and it
+                    // it is just something we need to skip altogether.
+                    //
+                    continue;
+                }
+
+                // Good token, not skipped, not EOF token
+                //
+                return  state->token;
+            }
+        }
+    }
 }
 
 /**
@@ -624,16 +644,16 @@ emit	    (pANTLR3_LEXER lexer)
     pANTLR3_COMMON_TOKEN	token;
 
     /* We could check pointers to token factories and so on, but
-     * we are in code that we want to run as fast as possible
-     * so we are not checking any errors. So make sure you have installed an input stream before
-     * trying to emit a new token.
-     */
+    * we are in code that we want to run as fast as possible
+    * so we are not checking any errors. So make sure you have installed an input stream before
+    * trying to emit a new token.
+    */
     token   = lexer->rec->state->tokFactory->newToken(lexer->rec->state->tokFactory);
 
     /* Install the supplied information, and some other bits we already know
-     * get added automatically, such as the input stream it is associated with
-     * (though it can all be overridden of course)
-     */
+    * get added automatically, such as the input stream it is associated with
+    * (though it can all be overridden of course)
+    */
     token->type		    = lexer->rec->state->type;
     token->channel	    = lexer->rec->state->channel;
     token->start	    = lexer->rec->state->tokenStartCharIndex;
@@ -641,20 +661,20 @@ emit	    (pANTLR3_LEXER lexer)
     token->line		    = lexer->rec->state->tokenStartLine;
     token->charPosition	= lexer->rec->state->tokenStartCharPositionInLine;
 
-	if	(lexer->rec->state->text != NULL)
-	{
-		token->textState		= ANTLR3_TEXT_STRING;
-		token->tokText.text	    = lexer->rec->state->text;
-	}
-	else
-	{
-		token->textState	= ANTLR3_TEXT_NONE;
-	}
+    if	(lexer->rec->state->text != NULL)
+    {
+        token->textState	    = ANTLR3_TEXT_STRING;
+        token->tokText.text	    = lexer->rec->state->text;
+    }
+    else
+    {
+        token->textState	= ANTLR3_TEXT_NONE;
+    }
     token->lineStart	= lexer->input->currentLine;
-	token->user1		= lexer->rec->state->user1;
-	token->user2		= lexer->rec->state->user2;
-	token->user3		= lexer->rec->state->user3;
-	token->custom		= lexer->rec->state->custom;
+    token->user1	= lexer->rec->state->user1;
+    token->user2	= lexer->rec->state->user2;
+    token->user3	= lexer->rec->state->user3;
+    token->custom	= lexer->rec->state->custom;
 
     lexer->rec->state->token	    = token;
 
@@ -846,7 +866,7 @@ getLine	    (pANTLR3_LEXER lexer)
 static ANTLR3_UINT32
 getCharPositionInLine	(pANTLR3_LEXER lexer)
 {
-    return  lexer->input->getCharPositionInLine(lexer->input);
+    return  lexer->input->charPositionInLine;
 }
 
 static ANTLR3_MARKER	getCharIndex	    (pANTLR3_LEXER lexer)
